@@ -571,18 +571,19 @@ class Application(
         except (ValueError, dbus_next.errors.DBusError) as ex:
             self.logger.error("Attach failed: %s, trying to import node", ex)
 
-            if isinstance(addr, int):
-                mesh_address = addr
-            elif isinstance(addr, Callable):
+            if isinstance(addr, Callable):
                 mesh_address = addr()
 
-            if isinstance(addr, Awaitable):
-                mesh_address = await addr
-
+                if isinstance(mesh_address, Awaitable):
+                    mesh_address = await mesh_address
             else:
+                mesh_address = addr
+
+            if not isinstance(mesh_address, int):
                 raise TypeError(
                     "Address not given as a value or an acceptable callback."
                 )
+
             await self.import_node(addr=mesh_address, iv_index=iv_index)
             configuration = await self.attach(**kwargs)
 
