@@ -29,7 +29,7 @@ from bluetooth_mesh.messages.generics import (
     TransitionTime,
     TransitionTimeAdapter,
 )
-from bluetooth_mesh.messages.util import EnumAdapter, Opcode
+from bluetooth_mesh.messages.util import EnumAdapter, Opcode, OpcodeMessage
 
 
 class LightLightnessOpcode(IntEnum):
@@ -48,6 +48,9 @@ class LightLightnessOpcode(IntEnum):
     LIGHTNESS_RANGE_GET = 0x8257
     LIGHTNESS_RANGE_STATUS = 0x8258
 
+    def __repr__(self):
+        return str(self.value)
+
 
 class LightLightnessSetupOpcode(IntEnum):
     LIGHTNESS_DEFAULT_SET = 0x8259
@@ -55,6 +58,9 @@ class LightLightnessSetupOpcode(IntEnum):
     LIGHTNESS_RANGE_SET = 0x825B
     LIGHTNESS_RANGE_SET_UNACKNOWLEDGED = 0x825C
 
+    def __repr__(self):
+        return str(self.value)
+
 
 # fmt: off
 LightLightnessGet = Struct()
@@ -103,39 +109,27 @@ LightLightnessSet = Select(
     LightLightnessSetMinimal
 )
 
-LightLightnessMessage = Struct(
-    "opcode" / EnumAdapter(Opcode, LightLightnessOpcode),
-    "params" / Switch(
-        this.opcode,
-        {
-            LightLightnessOpcode.LIGHTNESS_GET: LightLightnessGet,
-            LightLightnessOpcode.LIGHTNESS_SET: LightLightnessSet,
-            LightLightnessOpcode.LIGHTNESS_SET_UNACKNOWLEDGED: LightLightnessSet,
-            LightLightnessOpcode.LIGHTNESS_STATUS: LightLightnessStatus,
-            LightLightnessOpcode.LIGHTNESS_LINEAR_GET: LightLightnessGet,
-            LightLightnessOpcode.LIGHTNESS_LINEAR_SET: LightLightnessSet,
-            LightLightnessOpcode.LIGHTNESS_LINEAR_SET_UNACKNOWLEDGED: LightLightnessSet,
-            LightLightnessOpcode.LIGHTNESS_LINEAR_STATUS: LightLightnessStatus,
-            LightLightnessOpcode.LIGHTNESS_LAST_GET: LightLightnessGet,
-            LightLightnessOpcode.LIGHTNESS_LAST_STATUS: LightLightnessDefault,
-            LightLightnessOpcode.LIGHTNESS_DEFAULT_GET: LightLightnessGet,
-            LightLightnessOpcode.LIGHTNESS_DEFAULT_STATUS: LightLightnessDefault,
-            LightLightnessOpcode.LIGHTNESS_RANGE_GET: LightLightnessGet,
-            LightLightnessOpcode.LIGHTNESS_RANGE_STATUS: LightLightnessRangeStatus,
-        },
-    )
-)
+LightLightnessMessage = OpcodeMessage({
+    LightLightnessOpcode.LIGHTNESS_GET: LightLightnessGet,
+    LightLightnessOpcode.LIGHTNESS_SET: LightLightnessSet,
+    LightLightnessOpcode.LIGHTNESS_SET_UNACKNOWLEDGED: LightLightnessSet,
+    LightLightnessOpcode.LIGHTNESS_STATUS: LightLightnessStatus,
+    LightLightnessOpcode.LIGHTNESS_LINEAR_GET: LightLightnessGet,
+    LightLightnessOpcode.LIGHTNESS_LINEAR_SET: LightLightnessSet,
+    LightLightnessOpcode.LIGHTNESS_LINEAR_SET_UNACKNOWLEDGED: LightLightnessSet,
+    LightLightnessOpcode.LIGHTNESS_LINEAR_STATUS: LightLightnessStatus,
+    LightLightnessOpcode.LIGHTNESS_LAST_GET: LightLightnessGet,
+    LightLightnessOpcode.LIGHTNESS_LAST_STATUS: LightLightnessDefault,
+    LightLightnessOpcode.LIGHTNESS_DEFAULT_GET: LightLightnessGet,
+    LightLightnessOpcode.LIGHTNESS_DEFAULT_STATUS: LightLightnessDefault,
+    LightLightnessOpcode.LIGHTNESS_RANGE_GET: LightLightnessGet,
+    LightLightnessOpcode.LIGHTNESS_RANGE_STATUS: LightLightnessRangeStatus,
+})
 
-LightLightnessSetupMessage = Struct(
-    "opcode" / EnumAdapter(Opcode, LightLightnessSetupOpcode),
-    "params" / Switch(
-        this.opcode,
-        {
-            LightLightnessSetupOpcode.LIGHTNESS_DEFAULT_SET: LightLightnessDefault,
-            LightLightnessSetupOpcode.LIGHTNESS_DEFAULT_SET_UNACKNOWLEDGED: LightLightnessDefault,
-            LightLightnessSetupOpcode.LIGHTNESS_RANGE_SET: LightLightnessRange,
-            LightLightnessSetupOpcode.LIGHTNESS_RANGE_SET_UNACKNOWLEDGED: LightLightnessRange,
-        },
-    )
-)
+LightLightnessSetupMessage = OpcodeMessage({
+    LightLightnessSetupOpcode.LIGHTNESS_DEFAULT_SET: LightLightnessDefault,
+    LightLightnessSetupOpcode.LIGHTNESS_DEFAULT_SET_UNACKNOWLEDGED: LightLightnessDefault,
+    LightLightnessSetupOpcode.LIGHTNESS_RANGE_SET: LightLightnessRange,
+    LightLightnessSetupOpcode.LIGHTNESS_RANGE_SET_UNACKNOWLEDGED: LightLightnessRange,
+})
 # fmt: on
